@@ -10,6 +10,8 @@
 import re
 import requests
 from datetime import datetime
+from contants import *
+
 try:
     import simplejson as json
 except ImportError:
@@ -33,6 +35,7 @@ KORAIL_REFUND            = "%s.refunds.RefundsRequest" % KORAIL_MOBILE
 KORAIL_MYTICKETLIST      = "%s.myTicket.MyTicketList" % KORAIL_MOBILE
 
 KORAIL_MYRESERVATIONLIST = "%s.reservation.ReservationView" % KORAIL_MOBILE
+KORAIL_CANCEL            = "%s.reservationCancel.ReservationCancelChk" % KORAIL_MOBILE
 
 KORAIL_STATION_DB       = "%s.common.stationinfo?device=ip" % KORAIL_MOBILE
 KORAIL_STATION_DB_DATA  = "%s.common.stationdata" % KORAIL_MOBILE
@@ -91,9 +94,27 @@ class Schedule(object):
     #: 도착 시각 (hhmmss)
     arr_time = None # h_arv_tm
 
-    #: ???? 시각 (yyyyMMdd)
+    #: 운행 날짜 (yyyyMMdd)
     run_date = None # h_run_dt
 
+    def __init__(self, data):
+        self.train_type      = data.get('h_trn_clsf_cd')
+        self.train_type_name = data.get('h_trn_clsf_nm')
+        self.train_no        = data.get('h_trn_no')
+        self.delay_time      = data.get('h_expct_dlay_hr')
+
+        self.dep_name = data.get('h_dpt_rs_stn_nm')
+        self.dep_code = data.get('h_dpt_rs_stn_cd')
+        self.dep_date = data.get('h_dpt_dt')
+        self.dep_time = data.get('h_dpt_tm')
+
+        self.arr_name = data.get('h_arv_rs_stn_nm')
+        self.arr_code = data.get('h_arv_rs_stn_cd')
+        self.arr_date = data.get('h_arv_dt')
+        self.arr_time = data.get('h_arv_tm')
+
+        self.run_date = data.get('h_run_dt')
+
     def __repr__(self):
         dep_time = "%s:%s" % (self.dep_time[:2], self.dep_time[2:4])
         arr_time = "%s:%s" % (self.arr_time[:2], self.arr_time[2:4])
@@ -135,24 +156,27 @@ class Train(Schedule):
     #: 13: 매진
     general_seat = False # h_gen_rsv_cd
 
+    def __init__(self, data):
+        super(Train, self).__init__(data)
+        self.reserve_possible      = data.get('h_rsv_psb_flg')
+        self.reserve_possible_name = data.get('h_rsv_psb_nm')
+
+        self.special_seat = data.get('h_spe_rsv_cd')
+        self.general_seat = data.get('h_gen_rsv_cd')
+
     def __repr__(self):
-        repr_str = super(Train, self).__repr__() + " "
+        repr_str = super(Train, self).__repr__()
 
-        if self.special_seat != '00':
-            if  self.special_seat == '11':
-                special_seat = True
-            else:
-                special_seat = False
-            repr_str += '[특실:%d]' % special_seat
+        if self.reserve_possible_name is not None:
+            seats = []
+            if self.special_seat == '11':
+                seats.append("특실")
 
-        if self.general_seat != '00':
-            if  self.general_seat == '11':
-                general_seat = True
-            else:
-                general_seat = False
-            repr_str += '[일반실:%d]' % general_seat
+            if self.general_seat == '11':
+                seats.append("일반실")
+            repr_str += " "+ (",".join(seats)) + " " + self.reserve_possible_name.replace('\n',' ')
 
-        return repr_str + " " + self.reserve_possible_name.replace('\n',' ')
+        return repr_str
 
 
 class Ticket(Train):
@@ -191,6 +215,22 @@ class Ticket(Train):
     #: 구매 가격
     price = None # h_rcvd_amt  ex) 00013900
 
+    def __init__(self, data):
+        super(Ticket, self).__init__(data)
+        self.car_no        = data.get('h_srcar_no')
+        self.seat_no       = data.get('h_seat_no')
+        self.seat_no_end   = data.get('h_seat_no_end')
+        self.seat_no_count = int(data.get('h_seat_cnt'))
+
+        self.buyer_name = data.get('h_buy_ps_nm')
+        self.sale_date  = data.get('h_orgtk_sale_dt')
+        self.sale_info1 = data.get('h_orgtk_wct_no')
+        self.sale_info2 = data.get('h_orgtk_ret_sale_dt')
+        self.sale_info3 = data.get('h_orgtk_sale_sqno')
+        self.sale_info4 = data.get('h_orgtk_ret_pwd')
+        self.price      = int(data.get('h_rcvd_amt'))
+
+
     def __repr__(self):
         repr_str = super(Train, self).__repr__()
 
@@ -206,10 +246,52 @@ class Ticket(Train):
         return repr_str
 
     def get_ticket_no(self):
-        return "%s-%s-%s-%s" % (sale_info1,
-                                sale_info2,
-                                sale_info3,
-                                sale_info4)
+        return "-".join(map(str, (self.sale_info1, self.sale_info2, self.sale_info3, self.sale_info4)))
+
+
+class Passenger:
+    """승객. Passenger List를 검색과 예약에 쓰도록 한다."""
+    typecode = None           # txtPsgTpCd1    : '1',   #손님 종류 (어른 1, 어린이 3)
+    discount_type = '000'  # txtDiscKndCd1  : '000', #할인 타입 (경로, 동반유아, 군장병 등..)
+    count = 1          # txtCompaCnt1   : '1',   #인원수
+    card = ''           # txtCardCode_1  : '',    #할인카드 종류
+    card_no = ''        # txtCardNo_1    : '',    #할인카드 번호
+    card_pw = ''        # txtCardPw_1    : '',    #할인카드 비밀번호
+
+    def __init__(self, typecode=None, count=1, discount_type='000', card='', card_no='', card_pw=''):
+        self.typecode = typecode
+        self.count = count
+        self.discount_type = discount_type
+        self.card = card
+        self.card_no = card_no
+        self.card_pw = card_pw
+
+    def get_dict(self, index):
+        assert isinstance(index,int)
+        index = str(index)
+        return {
+            'txtPsgTpCd'+index: self.typecode,
+            'txtDiscKndCd'+index: self.discount_type,
+            'txtCompaCnt'+index: self.count,
+            'txtCardCode_'+index: self.card,
+            'txtCardNo_'+index: self.card_no,
+            'txtCardPw_'+index: self.card_pw,
+        }
+
+
+class AdultPassenger(Passenger):
+    def __init__(self, count=1, discount_type='000', card='', card_no='', card_pw=''):
+        Passenger.__init__(self, '1', count, discount_type, card, card_no, card_pw)
+
+
+class ChildPassenger(Passenger):
+    def __init__(self, count=1, discount_type='000', card='', card_no='', card_pw=''):
+        Passenger.__init__(self, '3', count, discount_type, card, card_no, card_pw)
+
+
+class SeniorPassenger(Passenger):
+    def __init__(self, count=1, discount_type='P41', card='', card_no='', card_pw=''):
+        Passenger.__init__(self, '1', count, discount_type, card, card_no, card_pw)
 
 
 class Reservation(Train):
@@ -218,6 +300,15 @@ class Reservation(Train):
     #: 예약번호
     rsv_id = None # h_pnr_no
 
+    #: 여정 번호
+    journey_no = None # txtJrnySqno
+
+    #: 여정 카운트
+    journey_cnt = None # txtJrnyCnt
+
+    #: 예약변경 번호?
+    rsv_chg_no = "00000"
+
     #: 자리 갯수
     seat_no_count = None # h_tot_seat_cnt  ex) 001
 
@@ -230,10 +321,39 @@ class Reservation(Train):
     #: 예약 가격
     price = None # h_rsv_amt  ex) 00013900
 
-    def __repr__(self):
-        repr_str = super(Train, self).__repr__()
+    #: 열차 번호 (Not implemented)
+    car_no = None # h_srcar_no
 
-        repr_str += ", %s원" % self.price
+    #: 자리 번호 (Not implemented)
+    seat_no = None # h_seat_no
+
+    #: 자리 번호 (Not implemented)
+    seat_no_end = None # h_seat_no_end
+
+    def __init__(self, data):
+        super(Reservation, self).__init__(data)
+        # 이 두 필드가 결과에 빠져있음
+        self.dep_date = data.get('h_run_dt')
+        self.arr_date = data.get('h_run_dt')
+
+        self.rsv_id         = data.get('h_pnr_no')
+        self.seat_no_count  = int(data.get('h_tot_seat_cnt'))
+        self.buy_limit_date = data.get('h_ntisu_lmt_dt')
+        self.buy_limit_time = data.get('h_ntisu_lmt_tm')
+        self.price          = int(data.get('h_rsv_amt'))
+        self.journey_no     = data.get('txtJrnySqno', "001")
+        self.journey_cnt    = data.get('txtJrnyCnt', "01")
+        self.rsv_chg_no     = data.get('hidRsvChgNo', "00000")
+
+        # 좌석정보 추가 업데이트 필요.
+        # self.car_no = None
+        # self.seat_no = None
+        # self.seat_no_end = None
+
+    def __repr__(self):
+        repr_str = super(Reservation, self).__repr__()
+
+        repr_str += ", %s원(%s석)" % (self.price, self.seat_no_count)
 
         buy_limit_time = "%s:%s" % (self.buy_limit_time[:2], self.buy_limit_time[2:4])
 
@@ -244,32 +364,43 @@ class Reservation(Train):
 
         return repr_str
 
-class Seat(Schedule):
-    """Ticket object"""
-    #: Schedule
-    schedule = None
 
-    #: 열차 번호
-    car_no = None # h_srcar_no
+class KorailError(Exception):
+    """Korail Base Error Class"""
+    codes = set()
 
-    #: 자리 번호
-    seat_no = None # h_seat_no
+    class __metaclass__(type):
+        def __contains__(cls, item):
+            return item in cls.codes
 
-    #: 자리 갯수
-    seat_no_count = None # h_seat_cnt  ex) 001
+    def __init__(self, msg, code):
+        self.msg = msg
+        self.code = code
 
-    def __repr__(self):
-        repr_str = self.schedule.__repr__()
-        repr_str += " %s호 %s" % (self.car_no, self.seat_no)
+    def __str__(self):
+        return "%s (%s)" % (self.msg, self.code)
 
-        return repr_str
 
-    def get_ticket_no(self):
-        return "%s-%s-%s-%s" % (sale_info1,
-                                sale_info2,
-                                sale_info3,
-                                sale_info4)
+class NeedToLoginError(KorailError):
+    """Korail NeedToLogin Error Class"""
+    codes = {'P058'}
 
+    def __init__(self, code=None):
+        KorailError.__init__(self, "Need to Login", code)
+
+
+class NoResultsError(KorailError):
+    """Korail NoResults Error Class"""
+    codes = {'P100'}
+
+    def __init__(self, code=None):
+        KorailError.__init__(self, "No Results", code)
+
+class SoldOutError(KorailError):
+    codes = {'ERR211161'}
+
+    def __init__(self, code=None):
+        KorailError.__init__(self, "Sold out", code)
 
 class Korail(object):
     """Korail object"""
@@ -293,13 +424,12 @@ class Korail(object):
 
     def login(self, id=None, password=None):
         """Login to Korail server.
-
-        :param id: `Korail membership number` or `phone number` or `email`
-                   membership   : xxxxxxxx (8 digits) 
-                   phone number : xxx-xxxx-xxxx
-                   email        : xxx@xxx.xxx
-        :param password: Korail account password
-        """
+:param id: `Korail membership number` or `phone number` or `email`
+    membership   : xxxxxxxx (8 digits)
+    phone number : xxx-xxxx-xxxx
+    email        : xxx@xxx.xxx
+:param password: Korail account password
+"""
         if id is None:
             id = self.id
         else:
@@ -359,34 +489,46 @@ class Korail(object):
             h_msg_cd  = j['h_msg_cd'].encode('utf-8')
             h_msg_txt = j['h_msg_txt'].encode('utf-8')
             # P058 : 로그인 필요
-            raise Exception("%s (%s)" % (h_msg_txt, h_msg_cd))
+            matched_error = filter(lambda x: h_msg_cd in x, (NoResultsError, NeedToLoginError, SoldOutError))
+            if matched_error:
+                raise matched_error[0](h_msg_cd)
+            else:
+                raise KorailError(h_msg_txt, h_msg_cd)
         else:
             return True
 
-    def search_train(self, dep, arr, date=None, time=None, train_type='05'):
+    def search_train(self, dep, arr, date=None, time=None, train_type='05',
+                     passengers=None):
         """Search trains for specific time and date.
 
-        :param dep: A departure station in Korean  ex) '서울'
-        :param arr: A arrival station in Korean  ex) '부산'
-        :param date: (optional) A departure date in `yyyyMMdd` format
-        :param time: (optional) A departure time in `hhmmss` format
-        :param train_type: (optional) A type of train
-                           - 00: KTX, KTX-산천
-                           - 01: 새마을호
-                           - 02: 무궁화호
-                           - 03: 통근열차
-                           - 04: 누리로
-                           - 05: 전체 (기본값)
-                           - 06: 공학직통
-                           - 07: KTX-산천
-                           - 08: ITX-새마을
-                           - 09: ITX-청춘
-        """
-        if date == None:
+:param dep: A departure station in Korean  ex) '서울'
+:param arr: A arrival station in Korean  ex) '부산'
+:param date: (optional) A departure date in `yyyyMMdd` format
+:param time: (optional) A departure time in `hhmmss` format
+:param train_type: (optional) A type of train
+                   - 00: KTX, KTX-산천
+                   - 01: 새마을호
+                   - 02: 무궁화호
+                   - 03: 통근열차
+                   - 04: 누리로
+                   - 05: 전체 (기본값)
+                   - 06: 공학직통
+                   - 07: KTX-산천
+                   - 08: ITX-새마을
+                   - 09: ITX-청춘
+"""
+        if date is None:
             date = datetime.now().strftime("%Y%m%d")
-        if time == None:
+        if time is None:
             time = datetime.now().strftime("%H%M%S")
 
+        if passengers is None:
+            passengers = [AdultPassenger()]
+
+        adult_count  = reduce(lambda a, b: a + b.count, filter(lambda x: isinstance(x, AdultPassenger), passengers), 0)
+        child_count  = reduce(lambda a, b: a + b.count, filter(lambda x: isinstance(x, ChildPassenger), passengers), 0)
+        senior_count = reduce(lambda a, b: a + b.count, filter(lambda x: isinstance(x, SeniorPassenger), passengers), 0)
+
         url  = KORAIL_SEARCH_SCHEDULE
         data = {
             'Device'         : self._device,
@@ -399,11 +541,11 @@ class Korail(object):
             'txtGoStart'     : dep,
             'txtGoEnd'       : arr,
             'txtGoHour'      : time, #'071500',
-            'txtPsgFlg_1'    : '1',  #일반인 1명
-            'txtPsgFlg_2'    : '0',
-            'txtPsgFlg_3'    : '0',
-            'txtPsgFlg_4'    : '0',
-            'txtPsgFlg_5'    : '0',
+            'txtPsgFlg_1'    : adult_count,  # 어른
+            'txtPsgFlg_2'    : child_count,  # 어린이
+            'txtPsgFlg_3'    : senior_count, # 경로
+            'txtPsgFlg_4'    : '0',  # 장애인1
+            'txtPsgFlg_5'    : '0',  # 장애인2
             'txtCardPsgCnt'  : '0',
             'txtSeatAttCd_2' : '00',
             'txtSeatAttCd_3' : '00',
@@ -426,39 +568,19 @@ class Korail(object):
                     try: info[i] = info[i].encode('utf-8')
                     except: pass
 
-                train = Train()
-                train.train_type      = info['h_trn_clsf_cd']
-                train.train_type_name = info['h_trn_clsf_nm']
-                train.train_no        = info['h_trn_no']
-                train.delay_time      = info['h_expct_dlay_hr']
-
-                train.dep_name = info['h_dpt_rs_stn_nm']
-                train.dep_code = info['h_dpt_rs_stn_cd']
-                train.dep_date = info['h_dpt_dt']
-                train.dep_time = info['h_dpt_tm']
-
-                train.arr_name = info['h_arv_rs_stn_nm']
-                train.arr_code = info['h_arv_rs_stn_cd']
-                train.arr_date = info['h_arv_dt']
-                train.arr_time = info['h_arv_tm']
-
-                train.run_date = info['h_run_dt']
-
-                train.reserve_possible      = info['h_rsv_psb_flg']
-                train.reserve_possible_name = info['h_rsv_psb_nm']
-
-                train.special_seat = info['h_spe_rsv_cd']
-                train.general_seat = info['h_gen_rsv_cd']
-
-                trains.append(train)
+                trains.append(Train(info))
 
             return trains
 
-    def reserve(self, train):
+    def reserve(self, train, passengers=None):
         """Reserve a train.
 
-        :param train: An instance of `Train`.
+:param train: An instance of `Train`.
         """
+        # train : 예약을 위한 차량의 필수 정보를 가진 모든 객체를 이용할 수 있어야 한다.
+        if passengers is None:
+            passengers = (AdultPassenger(),)
+
         url = KORAIL_TICKETRESERVATION
         data = {
             'Device'         : self._device,
@@ -476,12 +598,8 @@ class Korail(object):
             'txtMenuId'      : '11',
             'txtSrcarCnt'    : '0',
             'txtJrnyCnt'     : '1',
-            'txtPsgTpCd1'    : '1',
-            'txtDiscKndCd1'  : '000',
-            'txtCompaCnt1'   : '1',
-            'txtCardCode_1'  : '',
-            'txtCardNo_1'    : '',
-            'txtCardPw_1'    : '',
+
+            # 이하 여정정보1
             'txtJrnySqno1'   : '001',
             'txtJrnyTpCd1'   : '11',
             'txtDptDt1'      : train.dep_date,
@@ -493,6 +611,8 @@ class Korail(object):
             'txtTrnClsfCd1'  : train.train_type,
             'txtPsrmClCd1'   : '1',
             'txtChgFlg1'     : '',
+
+            # 이하 여정정보2
             'txtJrnySqno2'   : '',
             'txtJrnyTpCd2'   : '',
             'txtDptDt2'      : '',
@@ -504,54 +624,29 @@ class Korail(object):
             'txtTrnClsfCd2'  : '',
             'txtPsrmClCd2'   : '',
             'txtChgFlg2'     : '',
+
+            # 이하 txtTotPsgCnt 만큼 반복
+            # 'txtPsgTpCd1'    : '1',   #손님 종류 (어른, 어린이)
+            # 'txtDiscKndCd1'  : '000', #할인 타입 (경로, 동반유아, 군장병 등..)
+            # 'txtCompaCnt1'   : '1',   #인원수
+            # 'txtCardCode_1'  : '',
+            # 'txtCardNo_1'    : '',
+            # 'txtCardPw_1'    : '',
         }
 
+        index = 1
+        for psg in passengers:
+            data.update(psg.get_dict(index))
+            index += 1
+
         r = self._session.post(url, data=data)
         j = json.loads(r.text)
-
         if self._result_check(j):
-            journey_infos = j['jrny_infos']['jrny_info']
+            rsv_id = j['h_pnr_no']
+            rsvlist = filter(lambda x:x.rsv_id == rsv_id, self.reservations())
+            if len(rsvlist) == 1:
+                return rsvlist[0]
 
-            seats = []
-
-            for info in journey_infos:
-                for i in info:
-                    try: info[i] = info[i].encode('utf-8')
-                    except: pass
-
-                schedule = Schedule()
-
-                schedule.train_type      = info['h_trn_clsf_cd']
-                schedule.train_type_name = info['h_trn_clsf_nm']
-                schedule.train_no        = info['h_trn_no']
-
-                schedule.dep_name = info['h_dpt_rs_stn_nm']
-                schedule.dep_code = info['h_dpt_rs_stn_cd']
-                schedule.dep_date = info['h_dpt_dt']
-                schedule.dep_time = info['h_dpt_tm']
-
-                schedule.arr_name = info['h_arv_rs_stn_nm']
-                schedule.arr_code = info['h_arv_rs_stn_cd']
-                schedule.arr_date = ''
-                schedule.arr_time = ''
-
-                seat_infos = info['seat_infos']['seat_info']
-
-                for s_info in seat_infos:
-                    for i in s_info:
-                        try: s_info[i] = s_info[i].encode('utf-8')
-                        except: pass
-                    seat = Seat()
-
-                    seat.schedule      = schedule
-                    seat.car_no        = s_info['h_srcar_no']
-                    seat.seat_no       = s_info['h_seat_no']
-                    seat.seat_no_count = s_info['h_cont_seat_cnt']
-
-                    seats.append(seat)
-
-            return seats[0]
-    
     def tickets(self):
         """Get list of tickets"""
         url = KORAIL_MYTICKETLIST
@@ -574,44 +669,19 @@ class Korail(object):
 
             tickets = []
 
+            # http://stackoverflow.com/questions/1254454/fastest-way-to-convert-a-dicts-keys-values-from-unicode-to-str
+            # 위 코드 검증후 일괄 적용
             for info in ticket_infos:
                 for i in info:
                     try: info[i] = info[i].encode('utf-8')
                     except: pass
 
-                ticket = Ticket()
-                ticket.train_type      = info['h_trn_clsf_cd']
-                ticket.train_type_name = info['h_trn_clsf_nm']
-                ticket.train_no        = info['h_trn_no']
-
-                ticket.dep_name = info['h_dpt_rs_stn_nm']
-                ticket.dep_code = info['h_dpt_rs_stn_cd']
-                ticket.dep_date = info['h_dpt_dt']
-                ticket.dep_time = info['h_dpt_tm']
-
-                ticket.arr_name = info['h_arv_rs_stn_nm']
-                ticket.arr_code = info['h_arv_rs_stn_cd']
-                ticket.arr_date = info['h_arv_dt']
-                ticket.arr_time = info['h_arv_tm']
-
-                ticket.car_no        = info['h_srcar_no']
-                ticket.seat_no       = info['h_seat_no']
-                ticket.seat_no_end   = info['h_seat_no_end']
-                ticket.seat_no_count = int(info['h_seat_cnt'])
-
-                ticket.buyer_name = info['h_buy_ps_nm']
-                ticket.sale_date  = info['h_orgtk_sale_dt']
-                ticket.sale_info1 = info['h_orgtk_wct_no']
-                ticket.sale_info2 = info['h_orgtk_ret_sale_dt']
-                ticket.sale_info3 = info['h_orgtk_sale_sqno']
-                ticket.sale_info4 = info['h_orgtk_ret_pwd']
-                ticket.price      = int(info['h_rcvd_amt'])
-
-                tickets.append(ticket)
+                tickets.append(Ticket(info))
 
             return tickets
 
     def reservations(self):
+        """ Get My Reservations """
         url = KORAIL_MYRESERVATIONLIST
         data = {
             'Device'         : self._device,
@@ -620,42 +690,35 @@ class Korail(object):
         }
         r = self._session.post(url, data=data)
         j = json.loads(r.text)
+        try:
+            if self._result_check(j):
+                rsv_infos = j['jrny_infos']['jrny_info']
+
+                reserves = []
+
+                for info in rsv_infos:
+                    for i in info:
+                        try: info[i] = info[i].encode('utf-8')
+                        except: pass
+                    reserves.append(Reservation(info))
+                return reserves
+        except NoResultsError, e:
+            return []
+
+    def cancel(self, rsv):
+        """ Cancel Reservation : Canceling is for reservation, for ticket would be Refunding """
+        assert isinstance(rsv, Reservation)
+        url = KORAIL_CANCEL
+        data = {
+            'Device'         : self._device,
+            'Version'        : self._version,
+            'Key'            : self._key,
+            'txtPnrNo'       : rsv.rsv_id,
+            'txtJrnySqno'    : rsv.journey_no,
+            'txtJrnyCnt'     : rsv.journey_cnt,
+            'hidRsvChgNo'    : rsv.rsv_chg_no,
+        }
+        r = self._session.post(url, data=data)
+        j = json.loads(r.text)
         if self._result_check(j):
-            rsv_infos = j['jrny_infos']['jrny_info']
-
-            reserves = []
-
-            for info in rsv_infos:
-                for i in info:
-                    try: info[i] = info[i].encode('utf-8')
-                    except: pass
-
-                rsv = Reservation()
-                rsv.train_type      = info['h_trn_clsf_cd']
-                rsv.train_type_name = info['h_trn_clsf_nm']
-                rsv.train_no        = info['h_trn_no']
-
-                rsv.dep_name = info['h_dpt_rs_stn_nm']
-                rsv.dep_code = info['h_dpt_rs_stn_cd']
-                rsv.dep_date = info['h_run_dt']
-                rsv.dep_time = info['h_dpt_tm']
-
-                rsv.arr_name = info['h_arv_rs_stn_nm']
-                rsv.arr_code = info['h_arv_rs_stn_cd']
-                rsv.arr_date = info['h_run_dt']
-                rsv.arr_time = info['h_arv_tm']
-
-                rsv.rsv_id         = info['h_pnr_no']
-                rsv.seat_no_count  = int(info['h_tot_seat_cnt'])
-                rsv.buy_limit_date = info['h_ntisu_lmt_dt']
-                rsv.buy_limit_time = info['h_ntisu_lmt_tm']
-                rsv.price          = int(info['h_rsv_amt'])
-
-                reserves.append(rsv)
-
-            return reserves
-
-
-
-    def cancel(self):
-        pass
\ No newline at end of file
+            return True
